Class: Google::Apis::VideointelligenceV1::CloudVideoIntelligenceService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::VideointelligenceV1::CloudVideoIntelligenceService
- Defined in:
- lib/google/apis/videointelligence_v1/service.rb
Overview
Cloud Video Intelligence API
Detects objects, explicit content, and scene changes in videos. It also specifies the region for annotation and transcribes speech to text. Supports both asynchronous API and streaming API.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://videointelligence.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#annotate_video(google_cloud_videointelligence_v1_annotate_video_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VideointelligenceV1::GoogleLongrunningOperation
Performs asynchronous video annotation.
-
#cancel_operation_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VideointelligenceV1::GoogleProtobufEmpty
Starts asynchronous cancellation on a long-running operation.
-
#cancel_project_location_operation(name, google_longrunning_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VideointelligenceV1::GoogleProtobufEmpty
Starts asynchronous cancellation on a long-running operation.
-
#delete_operation_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VideointelligenceV1::GoogleProtobufEmpty
Deletes a long-running operation.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VideointelligenceV1::GoogleProtobufEmpty
Deletes a long-running operation.
-
#get_operation_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VideointelligenceV1::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VideointelligenceV1::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#initialize ⇒ CloudVideoIntelligenceService
constructor
A new instance of CloudVideoIntelligenceService.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VideointelligenceV1::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request.
Constructor Details
#initialize ⇒ CloudVideoIntelligenceService
Returns a new instance of CloudVideoIntelligenceService.
49 50 51 52 53 54 |
# File 'lib/google/apis/videointelligence_v1/service.rb', line 49 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-videointelligence_v1', client_version: Google::Apis::VideointelligenceV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
42 43 44 |
# File 'lib/google/apis/videointelligence_v1/service.rb', line 42 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
47 48 49 |
# File 'lib/google/apis/videointelligence_v1/service.rb', line 47 def quota_user @quota_user end |
Instance Method Details
#annotate_video(google_cloud_videointelligence_v1_annotate_video_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VideointelligenceV1::GoogleLongrunningOperation
Performs asynchronous video annotation. Progress and results can be retrieved
through the google.longrunning.Operations interface. Operation.metadata
contains AnnotateVideoProgress (progress). Operation.response contains
AnnotateVideoResponse (results).
332 333 334 335 336 337 338 339 340 341 |
# File 'lib/google/apis/videointelligence_v1/service.rb', line 332 def annotate_video(google_cloud_videointelligence_v1_annotate_video_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/videos:annotate', ) command.request_representation = Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1AnnotateVideoRequest::Representation command.request_object = google_cloud_videointelligence_v1_annotate_video_request_object command.response_representation = Google::Apis::VideointelligenceV1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::VideointelligenceV1::GoogleLongrunningOperation command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_operation_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VideointelligenceV1::GoogleProtobufEmpty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
83 84 85 86 87 88 89 90 91 |
# File 'lib/google/apis/videointelligence_v1/service.rb', line 83 def cancel_operation_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/operations/{+name}:cancel', ) command.response_representation = Google::Apis::VideointelligenceV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::VideointelligenceV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_project_location_operation(name, google_longrunning_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VideointelligenceV1::GoogleProtobufEmpty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/google/apis/videointelligence_v1/service.rb', line 185 def cancel_project_location_operation(name, google_longrunning_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::VideointelligenceV1::GoogleLongrunningCancelOperationRequest::Representation command.request_object = google_longrunning_cancel_operation_request_object command.response_representation = Google::Apis::VideointelligenceV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::VideointelligenceV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_operation_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VideointelligenceV1::GoogleProtobufEmpty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
116 117 118 119 120 121 122 123 124 |
# File 'lib/google/apis/videointelligence_v1/service.rb', line 116 def delete_operation_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/operations/{+name}', ) command.response_representation = Google::Apis::VideointelligenceV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::VideointelligenceV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VideointelligenceV1::GoogleProtobufEmpty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
220 221 222 223 224 225 226 227 228 |
# File 'lib/google/apis/videointelligence_v1/service.rb', line 220 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::VideointelligenceV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::VideointelligenceV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_operation_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VideointelligenceV1::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
147 148 149 150 151 152 153 154 155 |
# File 'lib/google/apis/videointelligence_v1/service.rb', line 147 def get_operation_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/operations/{+name}', ) command.response_representation = Google::Apis::VideointelligenceV1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::VideointelligenceV1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VideointelligenceV1::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
251 252 253 254 255 256 257 258 259 |
# File 'lib/google/apis/videointelligence_v1/service.rb', line 251 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::VideointelligenceV1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::VideointelligenceV1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::VideointelligenceV1::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/google/apis/videointelligence_v1/service.rb', line 296 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::VideointelligenceV1::GoogleLongrunningListOperationsResponse::Representation command.response_class = Google::Apis::VideointelligenceV1::GoogleLongrunningListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |