Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1ExportToOutputUriStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Status of exporting annotation response to user specified output_uri.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1ExportToOutputUriStatus

Returns a new instance of GoogleCloudVideointelligenceV1ExportToOutputUriStatus.



324
325
326
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 324

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stateString

Output only. State of the output_uri export. Corresponds to the JSON property state

Returns:

  • (String)


312
313
314
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 312

def state
  @state
end

#statusGoogle::Apis::VideointelligenceV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



322
323
324
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 322

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



329
330
331
332
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 329

def update!(**args)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
end