Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1LabelAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Label annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1LabelAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1LabelAnnotation.



511
512
513
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 511

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_entitiesArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1Entity>

Common categories for the detected entity. For example, when the label is Terrier, the category is likely dog. And in some cases there might be more than one categories e.g., Terrier could also be a pet. Corresponds to the JSON property categoryEntities



489
490
491
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 489

def category_entities
  @category_entities
end

#entityGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1Entity

Detected entity from video analysis. Corresponds to the JSON property entity



494
495
496
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 494

def entity
  @entity
end

#framesArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1LabelFrame>

All video frames where a label was detected. Corresponds to the JSON property frames



499
500
501
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 499

def frames
  @frames
end

#segmentsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1LabelSegment>

All video segments where a label was detected. Corresponds to the JSON property segments



504
505
506
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 504

def segments
  @segments
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


509
510
511
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 509

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



516
517
518
519
520
521
522
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 516

def update!(**args)
  @category_entities = args[:category_entities] if args.key?(:category_entities)
  @entity = args[:entity] if args.key?(:entity)
  @frames = args[:frames] if args.key?(:frames)
  @segments = args[:segments] if args.key?(:segments)
  @version = args[:version] if args.key?(:version)
end