Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1ObjectTrackingAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Annotations corresponding to one tracked object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1ObjectTrackingAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1ObjectTrackingAnnotation.



795
796
797
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

Object category's labeling confidence of this track. Corresponds to the JSON property confidence

Returns:

  • (Float)


761
762
763
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 761

def confidence
  @confidence
end

#entityGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1Entity

Detected entity from video analysis. Corresponds to the JSON property entity



766
767
768
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 766

def entity
  @entity
end

#framesArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1ObjectTrackingFrame>

Information corresponding to all frames where this object track appears. Non- streaming batch mode: it may be one or multiple ObjectTrackingFrame messages in frames. Streaming mode: it can only be one ObjectTrackingFrame message in frames. Corresponds to the JSON property frames



774
775
776
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 774

def frames
  @frames
end

#segmentGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1VideoSegment

Video segment. Corresponds to the JSON property segment



779
780
781
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 779

def segment
  @segment
end

#track_idFixnum

Streaming mode ONLY. In streaming mode, we do not know the end time of a tracked object before it is completed. Hence, there is no VideoSegment info returned. Instead, we provide a unique identifiable integer track_id so that the customers can correlate the results of the ongoing ObjectTrackAnnotation of the same track_id over time. Corresponds to the JSON property trackId

Returns:

  • (Fixnum)


788
789
790
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 788

def track_id
  @track_id
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


793
794
795
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 793

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



800
801
802
803
804
805
806
807
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 800

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @entity = args[:entity] if args.key?(:entity)
  @frames = args[:frames] if args.key?(:frames)
  @segment = args[:segment] if args.key?(:segment)
  @track_id = args[:track_id] if args.key?(:track_id)
  @version = args[:version] if args.key?(:version)
end