Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1SpeechTranscription
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1SpeechTranscription
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb
Overview
A speech recognition result corresponding to a portion of the audio.
Instance Attribute Summary collapse
-
#alternatives ⇒ Array<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1SpeechRecognitionAlternative>
May contain one or more recognition hypotheses (up to the maximum specified in
max_alternatives). -
#language_code ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1SpeechTranscription
constructor
A new instance of GoogleCloudVideointelligenceV1SpeechTranscription.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1SpeechTranscription
Returns a new instance of GoogleCloudVideointelligenceV1SpeechTranscription.
1021 1022 1023 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1021 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alternatives ⇒ Array<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1SpeechRecognitionAlternative>
May contain one or more recognition hypotheses (up to the maximum specified in
max_alternatives). These alternatives are ordered in terms of accuracy, with
the top (first) alternative being the most probable, as ranked by the
recognizer.
Corresponds to the JSON property alternatives
1012 1013 1014 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1012 def alternatives @alternatives end |
#language_code ⇒ String
Output only. The BCP-47
language tag of the language in this result. This language code was detected
to have the most likelihood of being spoken in the audio.
Corresponds to the JSON property languageCode
1019 1020 1021 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1019 def language_code @language_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1026 1027 1028 1029 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1026 def update!(**args) @alternatives = args[:alternatives] if args.key?(:alternatives) @language_code = args[:language_code] if args.key?(:language_code) end |