Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1Track
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1Track
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb
Overview
A track of an object instance.
Instance Attribute Summary collapse
-
#attributes ⇒ Array<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1DetectedAttribute>
Optional.
-
#confidence ⇒ Float
Optional.
-
#segment ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1VideoSegment
Video segment.
-
#timestamped_objects ⇒ Array<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1TimestampedObject>
The object with timestamp and attributes per frame in the track.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1Track
constructor
A new instance of GoogleCloudVideointelligenceV1Track.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1Track
Returns a new instance of GoogleCloudVideointelligenceV1Track.
1325 1326 1327 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1325 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Array<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1DetectedAttribute>
Optional. Attributes in the track level.
Corresponds to the JSON property attributes
1308 1309 1310 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1308 def attributes @attributes end |
#confidence ⇒ Float
Optional. The confidence score of the tracked object.
Corresponds to the JSON property confidence
1313 1314 1315 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1313 def confidence @confidence end |
#segment ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1VideoSegment
Video segment.
Corresponds to the JSON property segment
1318 1319 1320 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1318 def segment @segment end |
#timestamped_objects ⇒ Array<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1TimestampedObject>
The object with timestamp and attributes per frame in the track.
Corresponds to the JSON property timestampedObjects
1323 1324 1325 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1323 def @timestamped_objects end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1330 1331 1332 1333 1334 1335 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1330 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @confidence = args[:confidence] if args.key?(:confidence) @segment = args[:segment] if args.key?(:segment) @timestamped_objects = args[:timestamped_objects] if args.key?(:timestamped_objects) end |