Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1VideoAnnotationProgress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Annotation progress for a single video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1VideoAnnotationProgress

Returns a new instance of GoogleCloudVideointelligenceV1VideoAnnotationProgress.



1379
1380
1381
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1379

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_statusGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1ExportToOutputUriStatus

Status of exporting annotation response to user specified output_uri. Corresponds to the JSON property exportStatus



1345
1346
1347
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1345

def export_status
  @export_status
end

#featureString

Specifies which feature is being tracked if the request contains more than one feature. Corresponds to the JSON property feature

Returns:

  • (String)


1351
1352
1353
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1351

def feature
  @feature
end

#input_uriString

Video file location in Cloud Storage. Corresponds to the JSON property inputUri

Returns:

  • (String)


1356
1357
1358
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1356

def input_uri
  @input_uri
end

#progress_percentFixnum

Approximate percentage processed thus far. Guaranteed to be 100 when fully processed. Corresponds to the JSON property progressPercent

Returns:

  • (Fixnum)


1362
1363
1364
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1362

def progress_percent
  @progress_percent
end

#segmentGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1VideoSegment

Video segment. Corresponds to the JSON property segment



1367
1368
1369
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1367

def segment
  @segment
end

#start_timeString

Time when the request was received. Corresponds to the JSON property startTime

Returns:

  • (String)


1372
1373
1374
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1372

def start_time
  @start_time
end

#update_timeString

Time of the most recent update. Corresponds to the JSON property updateTime

Returns:

  • (String)


1377
1378
1379
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1377

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1384
1385
1386
1387
1388
1389
1390
1391
1392
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1384

def update!(**args)
  @export_status = args[:export_status] if args.key?(:export_status)
  @feature = args[:feature] if args.key?(:feature)
  @input_uri = args[:input_uri] if args.key?(:input_uri)
  @progress_percent = args[:progress_percent] if args.key?(:progress_percent)
  @segment = args[:segment] if args.key?(:segment)
  @start_time = args[:start_time] if args.key?(:start_time)
  @update_time = args[:update_time] if args.key?(:update_time)
end