Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1VideoAnnotationResults

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Annotation results for a single video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1VideoAnnotationResults

Returns a new instance of GoogleCloudVideointelligenceV1VideoAnnotationResults.



1504
1505
1506
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1504

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::VideointelligenceV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



1407
1408
1409
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1407

def error
  @error
end

#explicit_annotationGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1ExplicitContentAnnotation

Explicit content annotation (based on per-frame visual signals only). If no explicit content has been detected in a frame, no annotations are present for that frame. Corresponds to the JSON property explicitAnnotation



1414
1415
1416
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1414

def explicit_annotation
  @explicit_annotation
end

#face_annotationsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1FaceAnnotation>

Deprecated. Please use face_detection_annotations instead. Corresponds to the JSON property faceAnnotations



1419
1420
1421
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1419

def face_annotations
  @face_annotations
end

#face_detection_annotationsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1FaceDetectionAnnotation>

Face detection annotations. Corresponds to the JSON property faceDetectionAnnotations



1424
1425
1426
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1424

def face_detection_annotations
  @face_detection_annotations
end

#frame_label_annotationsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1LabelAnnotation>

Label annotations on frame level. There is exactly one element for each unique label. Corresponds to the JSON property frameLabelAnnotations



1430
1431
1432
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1430

def frame_label_annotations
  @frame_label_annotations
end

#input_uriString

Video file location in Cloud Storage. Corresponds to the JSON property inputUri

Returns:

  • (String)


1435
1436
1437
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1435

def input_uri
  @input_uri
end

#logo_recognition_annotationsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1LogoRecognitionAnnotation>

Annotations for list of logos detected, tracked and recognized in video. Corresponds to the JSON property logoRecognitionAnnotations



1440
1441
1442
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1440

def logo_recognition_annotations
  @logo_recognition_annotations
end

#object_annotationsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1ObjectTrackingAnnotation>

Annotations for list of objects detected and tracked in video. Corresponds to the JSON property objectAnnotations



1445
1446
1447
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1445

def object_annotations
  @object_annotations
end

#person_detection_annotationsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1PersonDetectionAnnotation>

Person detection annotations. Corresponds to the JSON property personDetectionAnnotations



1450
1451
1452
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1450

def person_detection_annotations
  @person_detection_annotations
end

#segmentGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1VideoSegment

Video segment. Corresponds to the JSON property segment



1455
1456
1457
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1455

def segment
  @segment
end

#segment_label_annotationsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1LabelAnnotation>

Topical label annotations on video level or user-specified segment level. There is exactly one element for each unique label. Corresponds to the JSON property segmentLabelAnnotations



1461
1462
1463
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1461

def segment_label_annotations
  @segment_label_annotations
end

#segment_presence_label_annotationsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1LabelAnnotation>

Presence label annotations on video level or user-specified segment level. There is exactly one element for each unique label. Compared to the existing topical segment_label_annotations, this field presents more fine-grained, segment-level labels detected in video content and is made available only when the client sets LabelDetectionConfig.model to "builtin/latest" in the request. Corresponds to the JSON property segmentPresenceLabelAnnotations



1471
1472
1473
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1471

def segment_presence_label_annotations
  @segment_presence_label_annotations
end

#shot_annotationsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1VideoSegment>

Shot annotations. Each shot is represented as a video segment. Corresponds to the JSON property shotAnnotations



1476
1477
1478
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1476

def shot_annotations
  @shot_annotations
end

#shot_label_annotationsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1LabelAnnotation>

Topical label annotations on shot level. There is exactly one element for each unique label. Corresponds to the JSON property shotLabelAnnotations



1482
1483
1484
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1482

def shot_label_annotations
  @shot_label_annotations
end

#shot_presence_label_annotationsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1LabelAnnotation>

Presence label annotations on shot level. There is exactly one element for each unique label. Compared to the existing topical shot_label_annotations, this field presents more fine-grained, shot-level labels detected in video content and is made available only when the client sets LabelDetectionConfig. model to "builtin/latest" in the request. Corresponds to the JSON property shotPresenceLabelAnnotations



1491
1492
1493
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1491

def shot_presence_label_annotations
  @shot_presence_label_annotations
end

#speech_transcriptionsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1SpeechTranscription>

Speech transcription. Corresponds to the JSON property speechTranscriptions



1496
1497
1498
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1496

def speech_transcriptions
  @speech_transcriptions
end

#text_annotationsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1TextAnnotation>

OCR text detection and tracking. Annotations for list of detected text snippets. Each will have list of frame information associated with it. Corresponds to the JSON property textAnnotations



1502
1503
1504
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1502

def text_annotations
  @text_annotations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1509

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @explicit_annotation = args[:explicit_annotation] if args.key?(:explicit_annotation)
  @face_annotations = args[:face_annotations] if args.key?(:face_annotations)
  @face_detection_annotations = args[:face_detection_annotations] if args.key?(:face_detection_annotations)
  @frame_label_annotations = args[:frame_label_annotations] if args.key?(:frame_label_annotations)
  @input_uri = args[:input_uri] if args.key?(:input_uri)
  @logo_recognition_annotations = args[:logo_recognition_annotations] if args.key?(:logo_recognition_annotations)
  @object_annotations = args[:object_annotations] if args.key?(:object_annotations)
  @person_detection_annotations = args[:person_detection_annotations] if args.key?(:person_detection_annotations)
  @segment = args[:segment] if args.key?(:segment)
  @segment_label_annotations = args[:segment_label_annotations] if args.key?(:segment_label_annotations)
  @segment_presence_label_annotations = args[:segment_presence_label_annotations] if args.key?(:segment_presence_label_annotations)
  @shot_annotations = args[:shot_annotations] if args.key?(:shot_annotations)
  @shot_label_annotations = args[:shot_label_annotations] if args.key?(:shot_label_annotations)
  @shot_presence_label_annotations = args[:shot_presence_label_annotations] if args.key?(:shot_presence_label_annotations)
  @speech_transcriptions = args[:speech_transcriptions] if args.key?(:speech_transcriptions)
  @text_annotations = args[:text_annotations] if args.key?(:text_annotations)
end