Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1VideoContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Video context and/or feature-specific parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1VideoContext

Returns a new instance of GoogleCloudVideointelligenceV1VideoContext.



1581
1582
1583
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1581

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#explicit_content_detection_configGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1ExplicitContentDetectionConfig

Config for EXPLICIT_CONTENT_DETECTION. Corresponds to the JSON property explicitContentDetectionConfig



1537
1538
1539
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1537

def explicit_content_detection_config
  @explicit_content_detection_config
end

#face_detection_configGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1FaceDetectionConfig

Config for FACE_DETECTION. Corresponds to the JSON property faceDetectionConfig



1542
1543
1544
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1542

def face_detection_config
  @face_detection_config
end

#label_detection_configGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1LabelDetectionConfig

Config for LABEL_DETECTION. Corresponds to the JSON property labelDetectionConfig



1547
1548
1549
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1547

def label_detection_config
  @label_detection_config
end

#object_tracking_configGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1ObjectTrackingConfig

Config for OBJECT_TRACKING. Corresponds to the JSON property objectTrackingConfig



1552
1553
1554
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1552

def object_tracking_config
  @object_tracking_config
end

#person_detection_configGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1PersonDetectionConfig

Config for PERSON_DETECTION. Corresponds to the JSON property personDetectionConfig



1557
1558
1559
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1557

def person_detection_config
  @person_detection_config
end

#segmentsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1VideoSegment>

Video segments to annotate. The segments may overlap and are not required to be contiguous or span the whole video. If unspecified, each video is treated as a single segment. Corresponds to the JSON property segments



1564
1565
1566
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1564

def segments
  @segments
end

#shot_change_detection_configGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1ShotChangeDetectionConfig

Config for SHOT_CHANGE_DETECTION. Corresponds to the JSON property shotChangeDetectionConfig



1569
1570
1571
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1569

def shot_change_detection_config
  @shot_change_detection_config
end

#speech_transcription_configGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1SpeechTranscriptionConfig

Config for SPEECH_TRANSCRIPTION. Corresponds to the JSON property speechTranscriptionConfig



1574
1575
1576
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1574

def speech_transcription_config
  @speech_transcription_config
end

#text_detection_configGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1TextDetectionConfig

Config for TEXT_DETECTION. Corresponds to the JSON property textDetectionConfig



1579
1580
1581
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1579

def text_detection_config
  @text_detection_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1586

def update!(**args)
  @explicit_content_detection_config = args[:explicit_content_detection_config] if args.key?(:explicit_content_detection_config)
  @face_detection_config = args[:face_detection_config] if args.key?(:face_detection_config)
  @label_detection_config = args[:label_detection_config] if args.key?(:label_detection_config)
  @object_tracking_config = args[:object_tracking_config] if args.key?(:object_tracking_config)
  @person_detection_config = args[:person_detection_config] if args.key?(:person_detection_config)
  @segments = args[:segments] if args.key?(:segments)
  @shot_change_detection_config = args[:shot_change_detection_config] if args.key?(:shot_change_detection_config)
  @speech_transcription_config = args[:speech_transcription_config] if args.key?(:speech_transcription_config)
  @text_detection_config = args[:text_detection_config] if args.key?(:text_detection_config)
end