Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2ExplicitContentAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Explicit content annotation (based on per-frame visual signals only). If no explicit content has been detected in a frame, no annotations are present for that frame.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2ExplicitContentAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1beta2ExplicitContentAnnotation.



1849
1850
1851
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1849

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#framesArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2ExplicitContentFrame>

All video frames where explicit content was detected. Corresponds to the JSON property frames



1842
1843
1844
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1842

def frames
  @frames
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


1847
1848
1849
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1847

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1854
1855
1856
1857
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1854

def update!(**args)
  @frames = args[:frames] if args.key?(:frames)
  @version = args[:version] if args.key?(:version)
end