Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2ExportToOutputUriStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Status of exporting annotation response to user specified output_uri.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2ExportToOutputUriStatus

Returns a new instance of GoogleCloudVideointelligenceV1beta2ExportToOutputUriStatus.



1905
1906
1907
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1905

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stateString

Output only. State of the output_uri export. Corresponds to the JSON property state

Returns:

  • (String)


1893
1894
1895
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1893

def state
  @state
end

#statusGoogle::Apis::VideointelligenceV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



1903
1904
1905
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1903

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1910
1911
1912
1913
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1910

def update!(**args)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
end