Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2LabelAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Label annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2LabelAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1beta2LabelAnnotation.



2057
2058
2059
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2057

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_entitiesArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2Entity>

Common categories for the detected entity. For example, when the label is Terrier, the category is likely dog. And in some cases there might be more than one categories e.g., Terrier could also be a pet. Corresponds to the JSON property categoryEntities



2035
2036
2037
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2035

def category_entities
  @category_entities
end

#entityGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2Entity

Detected entity from video analysis. Corresponds to the JSON property entity



2040
2041
2042
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2040

def entity
  @entity
end

#framesArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2LabelFrame>

All video frames where a label was detected. Corresponds to the JSON property frames



2045
2046
2047
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2045

def frames
  @frames
end

#segmentsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2LabelSegment>

All video segments where a label was detected. Corresponds to the JSON property segments



2050
2051
2052
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2050

def segments
  @segments
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


2055
2056
2057
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2055

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2062
2063
2064
2065
2066
2067
2068
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2062

def update!(**args)
  @category_entities = args[:category_entities] if args.key?(:category_entities)
  @entity = args[:entity] if args.key?(:entity)
  @frames = args[:frames] if args.key?(:frames)
  @segments = args[:segments] if args.key?(:segments)
  @version = args[:version] if args.key?(:version)
end