Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2LogoRecognitionAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Annotation corresponding to one detected, tracked and recognized logo class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2LogoRecognitionAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1beta2LogoRecognitionAnnotation.



2143
2144
2145
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2143

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entityGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2Entity

Detected entity from video analysis. Corresponds to the JSON property entity



2129
2130
2131
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2129

def entity
  @entity
end

#segmentsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2VideoSegment>

All video segments where the recognized logo appears. There might be multiple instances of the same logo class appearing in one VideoSegment. Corresponds to the JSON property segments



2135
2136
2137
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2135

def segments
  @segments
end

#tracksArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2Track>

All logo tracks where the recognized logo appears. Each track corresponds to one logo instance appearing in consecutive frames. Corresponds to the JSON property tracks



2141
2142
2143
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2141

def tracks
  @tracks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2148
2149
2150
2151
2152
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2148

def update!(**args)
  @entity = args[:entity] if args.key?(:entity)
  @segments = args[:segments] if args.key?(:segments)
  @tracks = args[:tracks] if args.key?(:tracks)
end