Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2ObjectTrackingFrame

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Video frame level annotations for object detection and tracking. This field stores per frame location, time offset, and confidence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2ObjectTrackingFrame

Returns a new instance of GoogleCloudVideointelligenceV1beta2ObjectTrackingFrame.



2316
2317
2318
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2316

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#normalized_bounding_boxGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2NormalizedBoundingBox

Normalized bounding box. The normalized vertex coordinates are relative to the original image. Range: [0, 1]. Corresponds to the JSON property normalizedBoundingBox



2309
2310
2311
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2309

def normalized_bounding_box
  @normalized_bounding_box
end

#time_offsetString

The timestamp of the frame in microseconds. Corresponds to the JSON property timeOffset

Returns:

  • (String)


2314
2315
2316
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2314

def time_offset
  @time_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2321
2322
2323
2324
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2321

def update!(**args)
  @normalized_bounding_box = args[:normalized_bounding_box] if args.key?(:normalized_bounding_box)
  @time_offset = args[:time_offset] if args.key?(:time_offset)
end