Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2SpeechTranscription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

A speech recognition result corresponding to a portion of the audio.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2SpeechTranscription

Returns a new instance of GoogleCloudVideointelligenceV1beta2SpeechTranscription.



2409
2410
2411
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2409

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alternativesArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2SpeechRecognitionAlternative>

May contain one or more recognition hypotheses (up to the maximum specified in max_alternatives). These alternatives are ordered in terms of accuracy, with the top (first) alternative being the most probable, as ranked by the recognizer. Corresponds to the JSON property alternatives



2400
2401
2402
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2400

def alternatives
  @alternatives
end

#language_codeString

Output only. The BCP-47 language tag of the language in this result. This language code was detected to have the most likelihood of being spoken in the audio. Corresponds to the JSON property languageCode

Returns:

  • (String)


2407
2408
2409
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2407

def language_code
  @language_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2414
2415
2416
2417
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2414

def update!(**args)
  @alternatives = args[:alternatives] if args.key?(:alternatives)
  @language_code = args[:language_code] if args.key?(:language_code)
end