Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2VideoAnnotationProgress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Annotation progress for a single video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2VideoAnnotationProgress

Returns a new instance of GoogleCloudVideointelligenceV1beta2VideoAnnotationProgress.



2636
2637
2638
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2636

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_statusGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2ExportToOutputUriStatus

Status of exporting annotation response to user specified output_uri. Corresponds to the JSON property exportStatus



2602
2603
2604
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2602

def export_status
  @export_status
end

#featureString

Specifies which feature is being tracked if the request contains more than one feature. Corresponds to the JSON property feature

Returns:

  • (String)


2608
2609
2610
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2608

def feature
  @feature
end

#input_uriString

Video file location in Cloud Storage. Corresponds to the JSON property inputUri

Returns:

  • (String)


2613
2614
2615
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2613

def input_uri
  @input_uri
end

#progress_percentFixnum

Approximate percentage processed thus far. Guaranteed to be 100 when fully processed. Corresponds to the JSON property progressPercent

Returns:

  • (Fixnum)


2619
2620
2621
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2619

def progress_percent
  @progress_percent
end

#segmentGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2VideoSegment

Video segment. Corresponds to the JSON property segment



2624
2625
2626
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2624

def segment
  @segment
end

#start_timeString

Time when the request was received. Corresponds to the JSON property startTime

Returns:

  • (String)


2629
2630
2631
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2629

def start_time
  @start_time
end

#update_timeString

Time of the most recent update. Corresponds to the JSON property updateTime

Returns:

  • (String)


2634
2635
2636
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2634

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2641
2642
2643
2644
2645
2646
2647
2648
2649
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2641

def update!(**args)
  @export_status = args[:export_status] if args.key?(:export_status)
  @feature = args[:feature] if args.key?(:feature)
  @input_uri = args[:input_uri] if args.key?(:input_uri)
  @progress_percent = args[:progress_percent] if args.key?(:progress_percent)
  @segment = args[:segment] if args.key?(:segment)
  @start_time = args[:start_time] if args.key?(:start_time)
  @update_time = args[:update_time] if args.key?(:update_time)
end