Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1beta2WordInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Word-specific information for recognized words. Word information is only included in the response when certain request parameters are set, such as enable_word_time_offsets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2WordInfo

Returns a new instance of GoogleCloudVideointelligenceV1beta2WordInfo.



2866
2867
2868
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2866

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

Output only. The confidence estimate between 0.0 and 1.0. A higher number indicates an estimated greater likelihood that the recognized words are correct. This field is set only for the top alternative. This field is not guaranteed to be accurate and users should not rely on it to be always provided. The default of 0.0 is a sentinel value indicating confidence was not set. Corresponds to the JSON property confidence

Returns:

  • (Float)


2828
2829
2830
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2828

def confidence
  @confidence
end

#end_timeString

Time offset relative to the beginning of the audio, and corresponding to the end of the spoken word. This field is only set if enable_word_time_offsets= true and only in the top hypothesis. This is an experimental feature and the accuracy of the time offset can vary. Corresponds to the JSON property endTime

Returns:

  • (String)


2836
2837
2838
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2836

def end_time
  @end_time
end

#speaker_labelString

Output only. A distinct string value is assigned for every speaker within the audio. This field specifies which one of those speakers was detected to have spoken this word. Corresponds to the JSON property speakerLabel

Returns:

  • (String)


2843
2844
2845
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2843

def speaker_label
  @speaker_label
end

#speaker_tagFixnum

Output only. A distinct integer value is assigned for every speaker within the audio. This field specifies which one of those speakers was detected to have spoken this word. Value ranges from 1 up to diarization_speaker_count, and is only set if speaker diarization is enabled. Corresponds to the JSON property speakerTag

Returns:

  • (Fixnum)


2851
2852
2853
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2851

def speaker_tag
  @speaker_tag
end

#start_timeString

Time offset relative to the beginning of the audio, and corresponding to the start of the spoken word. This field is only set if enable_word_time_offsets= true and only in the top hypothesis. This is an experimental feature and the accuracy of the time offset can vary. Corresponds to the JSON property startTime

Returns:

  • (String)


2859
2860
2861
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2859

def start_time
  @start_time
end

#wordString

The word corresponding to this set of information. Corresponds to the JSON property word

Returns:

  • (String)


2864
2865
2866
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2864

def word
  @word
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2871
2872
2873
2874
2875
2876
2877
2878
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2871

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @end_time = args[:end_time] if args.key?(:end_time)
  @speaker_label = args[:speaker_label] if args.key?(:speaker_label)
  @speaker_tag = args[:speaker_tag] if args.key?(:speaker_tag)
  @start_time = args[:start_time] if args.key?(:start_time)
  @word = args[:word] if args.key?(:word)
end