Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1DetectedAttribute
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1DetectedAttribute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb
Overview
A generic detected attribute represented by name in string format.
Instance Attribute Summary collapse
-
#confidence ⇒ Float
Detected attribute confidence.
-
#name ⇒ String
The name of the attribute, for example, glasses, dark_glasses, mouth_open.
-
#value ⇒ String
Text value of the detection result.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1DetectedAttribute
constructor
A new instance of GoogleCloudVideointelligenceV1p1beta1DetectedAttribute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1DetectedAttribute
Returns a new instance of GoogleCloudVideointelligenceV1p1beta1DetectedAttribute.
2944 2945 2946 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2944 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
Detected attribute confidence. Range [0, 1].
Corresponds to the JSON property confidence
2930 2931 2932 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2930 def confidence @confidence end |
#name ⇒ String
The name of the attribute, for example, glasses, dark_glasses, mouth_open. A
full list of supported type names will be provided in the document.
Corresponds to the JSON property name
2936 2937 2938 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2936 def name @name end |
#value ⇒ String
Text value of the detection result. For example, the value for "HairColor" can
be "black", "blonde", etc.
Corresponds to the JSON property value
2942 2943 2944 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2942 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2949 2950 2951 2952 2953 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2949 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @name = args[:name] if args.key?(:name) @value = args[:value] if args.key?(:value) end |