Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1DetectedLandmark

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

A generic detected landmark represented by name in string format and a 2D location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1DetectedLandmark

Returns a new instance of GoogleCloudVideointelligenceV1p1beta1DetectedLandmark.



2977
2978
2979
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2977

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

The confidence score of the detected landmark. Range [0, 1]. Corresponds to the JSON property confidence

Returns:

  • (Float)


2964
2965
2966
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2964

def confidence
  @confidence
end

#nameString

The name of this landmark, for example, left_hand, right_shoulder. Corresponds to the JSON property name

Returns:

  • (String)


2969
2970
2971
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2969

def name
  @name
end

#pointGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1NormalizedVertex

A vertex represents a 2D point in the image. NOTE: the normalized vertex coordinates are relative to the original image and range from 0 to 1. Corresponds to the JSON property point



2975
2976
2977
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2975

def point
  @point
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2982
2983
2984
2985
2986
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 2982

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @name = args[:name] if args.key?(:name)
  @point = args[:point] if args.key?(:point)
end