Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1ExplicitContentAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Explicit content annotation (based on per-frame visual signals only). If no explicit content has been detected in a frame, no annotations are present for that frame.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1ExplicitContentAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1p1beta1ExplicitContentAnnotation.



3037
3038
3039
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3037

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#framesArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1ExplicitContentFrame>

All video frames where explicit content was detected. Corresponds to the JSON property frames



3030
3031
3032
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3030

def frames
  @frames
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


3035
3036
3037
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3035

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3042
3043
3044
3045
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3042

def update!(**args)
  @frames = args[:frames] if args.key?(:frames)
  @version = args[:version] if args.key?(:version)
end