Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1ExplicitContentFrame
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1ExplicitContentFrame
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb
Overview
Video frame level annotation results for explicit content.
Instance Attribute Summary collapse
-
#pornography_likelihood ⇒ String
Likelihood of the pornography content..
-
#time_offset ⇒ String
Time-offset, relative to the beginning of the video, corresponding to the video frame for this location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1ExplicitContentFrame
constructor
A new instance of GoogleCloudVideointelligenceV1p1beta1ExplicitContentFrame.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1ExplicitContentFrame
Returns a new instance of GoogleCloudVideointelligenceV1p1beta1ExplicitContentFrame.
3063 3064 3065 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3063 def initialize(**args) update!(**args) end |
Instance Attribute Details
#pornography_likelihood ⇒ String
Likelihood of the pornography content..
Corresponds to the JSON property pornographyLikelihood
3055 3056 3057 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3055 def pornography_likelihood @pornography_likelihood end |
#time_offset ⇒ String
Time-offset, relative to the beginning of the video, corresponding to the
video frame for this location.
Corresponds to the JSON property timeOffset
3061 3062 3063 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3061 def time_offset @time_offset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3068 3069 3070 3071 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3068 def update!(**args) @pornography_likelihood = args[:pornography_likelihood] if args.key?(:pornography_likelihood) @time_offset = args[:time_offset] if args.key?(:time_offset) end |