Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1ExportToOutputUriStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Status of exporting annotation response to user specified output_uri.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1ExportToOutputUriStatus

Returns a new instance of GoogleCloudVideointelligenceV1p1beta1ExportToOutputUriStatus.



3093
3094
3095
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3093

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stateString

Output only. State of the output_uri export. Corresponds to the JSON property state

Returns:

  • (String)


3081
3082
3083
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3081

def state
  @state
end

#statusGoogle::Apis::VideointelligenceV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



3091
3092
3093
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3091

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3098
3099
3100
3101
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3098

def update!(**args)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
end