Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1LabelAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Label annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1LabelAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1p1beta1LabelAnnotation.



3245
3246
3247
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3245

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_entitiesArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1Entity>

Common categories for the detected entity. For example, when the label is Terrier, the category is likely dog. And in some cases there might be more than one categories e.g., Terrier could also be a pet. Corresponds to the JSON property categoryEntities



3223
3224
3225
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3223

def category_entities
  @category_entities
end

#entityGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1Entity

Detected entity from video analysis. Corresponds to the JSON property entity



3228
3229
3230
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3228

def entity
  @entity
end

#framesArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1LabelFrame>

All video frames where a label was detected. Corresponds to the JSON property frames



3233
3234
3235
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3233

def frames
  @frames
end

#segmentsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1LabelSegment>

All video segments where a label was detected. Corresponds to the JSON property segments



3238
3239
3240
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3238

def segments
  @segments
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


3243
3244
3245
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3243

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3250
3251
3252
3253
3254
3255
3256
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3250

def update!(**args)
  @category_entities = args[:category_entities] if args.key?(:category_entities)
  @entity = args[:entity] if args.key?(:entity)
  @frames = args[:frames] if args.key?(:frames)
  @segments = args[:segments] if args.key?(:segments)
  @version = args[:version] if args.key?(:version)
end