Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1VideoAnnotationProgress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Annotation progress for a single video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1VideoAnnotationProgress

Returns a new instance of GoogleCloudVideointelligenceV1p1beta1VideoAnnotationProgress.



3824
3825
3826
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3824

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_statusGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1ExportToOutputUriStatus

Status of exporting annotation response to user specified output_uri. Corresponds to the JSON property exportStatus



3790
3791
3792
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3790

def export_status
  @export_status
end

#featureString

Specifies which feature is being tracked if the request contains more than one feature. Corresponds to the JSON property feature

Returns:

  • (String)


3796
3797
3798
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3796

def feature
  @feature
end

#input_uriString

Video file location in Cloud Storage. Corresponds to the JSON property inputUri

Returns:

  • (String)


3801
3802
3803
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3801

def input_uri
  @input_uri
end

#progress_percentFixnum

Approximate percentage processed thus far. Guaranteed to be 100 when fully processed. Corresponds to the JSON property progressPercent

Returns:

  • (Fixnum)


3807
3808
3809
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3807

def progress_percent
  @progress_percent
end

#segmentGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1VideoSegment

Video segment. Corresponds to the JSON property segment



3812
3813
3814
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3812

def segment
  @segment
end

#start_timeString

Time when the request was received. Corresponds to the JSON property startTime

Returns:

  • (String)


3817
3818
3819
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3817

def start_time
  @start_time
end

#update_timeString

Time of the most recent update. Corresponds to the JSON property updateTime

Returns:

  • (String)


3822
3823
3824
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3822

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3829
3830
3831
3832
3833
3834
3835
3836
3837
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3829

def update!(**args)
  @export_status = args[:export_status] if args.key?(:export_status)
  @feature = args[:feature] if args.key?(:feature)
  @input_uri = args[:input_uri] if args.key?(:input_uri)
  @progress_percent = args[:progress_percent] if args.key?(:progress_percent)
  @segment = args[:segment] if args.key?(:segment)
  @start_time = args[:start_time] if args.key?(:start_time)
  @update_time = args[:update_time] if args.key?(:update_time)
end