Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1WordInfo
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1WordInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb
Overview
Word-specific information for recognized words. Word information is only
included in the response when certain request parameters are set, such as
enable_word_time_offsets.
Instance Attribute Summary collapse
-
#confidence ⇒ Float
Output only.
-
#end_time ⇒ String
Time offset relative to the beginning of the audio, and corresponding to the end of the spoken word.
-
#speaker_label ⇒ String
Output only.
-
#speaker_tag ⇒ Fixnum
Output only.
-
#start_time ⇒ String
Time offset relative to the beginning of the audio, and corresponding to the start of the spoken word.
-
#word ⇒ String
The word corresponding to this set of information.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1WordInfo
constructor
A new instance of GoogleCloudVideointelligenceV1p1beta1WordInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1WordInfo
Returns a new instance of GoogleCloudVideointelligenceV1p1beta1WordInfo.
4054 4055 4056 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4054 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
Output only. The confidence estimate between 0.0 and 1.0. A higher number
indicates an estimated greater likelihood that the recognized words are
correct. This field is set only for the top alternative. This field is not
guaranteed to be accurate and users should not rely on it to be always
provided. The default of 0.0 is a sentinel value indicating confidence was
not set.
Corresponds to the JSON property confidence
4016 4017 4018 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4016 def confidence @confidence end |
#end_time ⇒ String
Time offset relative to the beginning of the audio, and corresponding to the
end of the spoken word. This field is only set if enable_word_time_offsets=
true and only in the top hypothesis. This is an experimental feature and the
accuracy of the time offset can vary.
Corresponds to the JSON property endTime
4024 4025 4026 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4024 def end_time @end_time end |
#speaker_label ⇒ String
Output only. A distinct string value is assigned for every speaker within the
audio. This field specifies which one of those speakers was detected to have
spoken this word.
Corresponds to the JSON property speakerLabel
4031 4032 4033 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4031 def speaker_label @speaker_label end |
#speaker_tag ⇒ Fixnum
Output only. A distinct integer value is assigned for every speaker within the
audio. This field specifies which one of those speakers was detected to have
spoken this word. Value ranges from 1 up to diarization_speaker_count, and is
only set if speaker diarization is enabled.
Corresponds to the JSON property speakerTag
4039 4040 4041 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4039 def speaker_tag @speaker_tag end |
#start_time ⇒ String
Time offset relative to the beginning of the audio, and corresponding to the
start of the spoken word. This field is only set if enable_word_time_offsets=
true and only in the top hypothesis. This is an experimental feature and the
accuracy of the time offset can vary.
Corresponds to the JSON property startTime
4047 4048 4049 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4047 def start_time @start_time end |
#word ⇒ String
The word corresponding to this set of information.
Corresponds to the JSON property word
4052 4053 4054 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4052 def word @word end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4059 4060 4061 4062 4063 4064 4065 4066 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4059 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @end_time = args[:end_time] if args.key?(:end_time) @speaker_label = args[:speaker_label] if args.key?(:speaker_label) @speaker_tag = args[:speaker_tag] if args.key?(:speaker_tag) @start_time = args[:start_time] if args.key?(:start_time) @word = args[:word] if args.key?(:word) end |