Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1LabelAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Label annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1LabelAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1p2beta1LabelAnnotation.



4433
4434
4435
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4433

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_entitiesArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1Entity>

Common categories for the detected entity. For example, when the label is Terrier, the category is likely dog. And in some cases there might be more than one categories e.g., Terrier could also be a pet. Corresponds to the JSON property categoryEntities



4411
4412
4413
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4411

def category_entities
  @category_entities
end

#entityGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1Entity

Detected entity from video analysis. Corresponds to the JSON property entity



4416
4417
4418
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4416

def entity
  @entity
end

#framesArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1LabelFrame>

All video frames where a label was detected. Corresponds to the JSON property frames



4421
4422
4423
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4421

def frames
  @frames
end

#segmentsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1LabelSegment>

All video segments where a label was detected. Corresponds to the JSON property segments



4426
4427
4428
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4426

def segments
  @segments
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


4431
4432
4433
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4431

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4438
4439
4440
4441
4442
4443
4444
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4438

def update!(**args)
  @category_entities = args[:category_entities] if args.key?(:category_entities)
  @entity = args[:entity] if args.key?(:entity)
  @frames = args[:frames] if args.key?(:frames)
  @segments = args[:segments] if args.key?(:segments)
  @version = args[:version] if args.key?(:version)
end