Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1ObjectTrackingAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1ObjectTrackingAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb
Overview
Annotations corresponding to one tracked object.
Instance Attribute Summary collapse
-
#confidence ⇒ Float
Object category's labeling confidence of this track.
-
#entity ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1Entity
Detected entity from video analysis.
-
#frames ⇒ Array<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1ObjectTrackingFrame>
Information corresponding to all frames where this object track appears.
-
#segment ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1VideoSegment
Video segment.
-
#track_id ⇒ Fixnum
Streaming mode ONLY.
-
#version ⇒ String
Feature version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1ObjectTrackingAnnotation
constructor
A new instance of GoogleCloudVideointelligenceV1p2beta1ObjectTrackingAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1ObjectTrackingAnnotation
Returns a new instance of GoogleCloudVideointelligenceV1p2beta1ObjectTrackingAnnotation.
4661 4662 4663 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4661 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
Object category's labeling confidence of this track.
Corresponds to the JSON property confidence
4627 4628 4629 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4627 def confidence @confidence end |
#entity ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1Entity
Detected entity from video analysis.
Corresponds to the JSON property entity
4632 4633 4634 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4632 def entity @entity end |
#frames ⇒ Array<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1ObjectTrackingFrame>
Information corresponding to all frames where this object track appears. Non-
streaming batch mode: it may be one or multiple ObjectTrackingFrame messages
in frames. Streaming mode: it can only be one ObjectTrackingFrame message in
frames.
Corresponds to the JSON property frames
4640 4641 4642 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4640 def frames @frames end |
#segment ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1VideoSegment
Video segment.
Corresponds to the JSON property segment
4645 4646 4647 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4645 def segment @segment end |
#track_id ⇒ Fixnum
Streaming mode ONLY. In streaming mode, we do not know the end time of a
tracked object before it is completed. Hence, there is no VideoSegment info
returned. Instead, we provide a unique identifiable integer track_id so that
the customers can correlate the results of the ongoing ObjectTrackAnnotation
of the same track_id over time.
Corresponds to the JSON property trackId
4654 4655 4656 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4654 def track_id @track_id end |
#version ⇒ String
Feature version.
Corresponds to the JSON property version
4659 4660 4661 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4659 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4666 4667 4668 4669 4670 4671 4672 4673 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4666 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @entity = args[:entity] if args.key?(:entity) @frames = args[:frames] if args.key?(:frames) @segment = args[:segment] if args.key?(:segment) @track_id = args[:track_id] if args.key?(:track_id) @version = args[:version] if args.key?(:version) end |