Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Annotation progress for a single video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress

Returns a new instance of GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress.



5012
5013
5014
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5012

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_statusGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1ExportToOutputUriStatus

Status of exporting annotation response to user specified output_uri. Corresponds to the JSON property exportStatus



4978
4979
4980
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4978

def export_status
  @export_status
end

#featureString

Specifies which feature is being tracked if the request contains more than one feature. Corresponds to the JSON property feature

Returns:

  • (String)


4984
4985
4986
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4984

def feature
  @feature
end

#input_uriString

Video file location in Cloud Storage. Corresponds to the JSON property inputUri

Returns:

  • (String)


4989
4990
4991
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4989

def input_uri
  @input_uri
end

#progress_percentFixnum

Approximate percentage processed thus far. Guaranteed to be 100 when fully processed. Corresponds to the JSON property progressPercent

Returns:

  • (Fixnum)


4995
4996
4997
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4995

def progress_percent
  @progress_percent
end

#segmentGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1VideoSegment

Video segment. Corresponds to the JSON property segment



5000
5001
5002
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5000

def segment
  @segment
end

#start_timeString

Time when the request was received. Corresponds to the JSON property startTime

Returns:

  • (String)


5005
5006
5007
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5005

def start_time
  @start_time
end

#update_timeString

Time of the most recent update. Corresponds to the JSON property updateTime

Returns:

  • (String)


5010
5011
5012
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5010

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5017
5018
5019
5020
5021
5022
5023
5024
5025
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5017

def update!(**args)
  @export_status = args[:export_status] if args.key?(:export_status)
  @feature = args[:feature] if args.key?(:feature)
  @input_uri = args[:input_uri] if args.key?(:input_uri)
  @progress_percent = args[:progress_percent] if args.key?(:progress_percent)
  @segment = args[:segment] if args.key?(:segment)
  @start_time = args[:start_time] if args.key?(:start_time)
  @update_time = args[:update_time] if args.key?(:update_time)
end