Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1VideoSegment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Video segment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1VideoSegment

Returns a new instance of GoogleCloudVideointelligenceV1p2beta1VideoSegment.



5179
5180
5181
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5179

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_time_offsetString

Time-offset, relative to the beginning of the video, corresponding to the end of the segment (inclusive). Corresponds to the JSON property endTimeOffset

Returns:

  • (String)


5171
5172
5173
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5171

def end_time_offset
  @end_time_offset
end

#start_time_offsetString

Time-offset, relative to the beginning of the video, corresponding to the start of the segment (inclusive). Corresponds to the JSON property startTimeOffset

Returns:

  • (String)


5177
5178
5179
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5177

def start_time_offset
  @start_time_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5184
5185
5186
5187
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5184

def update!(**args)
  @end_time_offset = args[:end_time_offset] if args.key?(:end_time_offset)
  @start_time_offset = args[:start_time_offset] if args.key?(:start_time_offset)
end