Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1Celebrity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Celebrity definition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1Celebrity

Returns a new instance of GoogleCloudVideointelligenceV1p3beta1Celebrity.



5321
5322
5323
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5321

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Textual description of additional information about the celebrity, if applicable. Corresponds to the JSON property description

Returns:

  • (String)


5307
5308
5309
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5307

def description
  @description
end

#display_nameString

The celebrity name. Corresponds to the JSON property displayName

Returns:

  • (String)


5312
5313
5314
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5312

def display_name
  @display_name
end

#nameString

The resource name of the celebrity. Have the format video-intelligence/kg-mid indicates a celebrity from preloaded gallery. kg-mid is the id in Google knowledge graph, which is unique for the celebrity. Corresponds to the JSON property name

Returns:

  • (String)


5319
5320
5321
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5319

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5326
5327
5328
5329
5330
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5326

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
end