Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1DetectedAttribute
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1DetectedAttribute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb
Overview
A generic detected attribute represented by name in string format.
Instance Attribute Summary collapse
-
#confidence ⇒ Float
Detected attribute confidence.
-
#name ⇒ String
The name of the attribute, for example, glasses, dark_glasses, mouth_open.
-
#value ⇒ String
Text value of the detection result.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1DetectedAttribute
constructor
A new instance of GoogleCloudVideointelligenceV1p3beta1DetectedAttribute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1DetectedAttribute
Returns a new instance of GoogleCloudVideointelligenceV1p3beta1DetectedAttribute.
5406 5407 5408 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5406 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
Detected attribute confidence. Range [0, 1].
Corresponds to the JSON property confidence
5392 5393 5394 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5392 def confidence @confidence end |
#name ⇒ String
The name of the attribute, for example, glasses, dark_glasses, mouth_open. A
full list of supported type names will be provided in the document.
Corresponds to the JSON property name
5398 5399 5400 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5398 def name @name end |
#value ⇒ String
Text value of the detection result. For example, the value for "HairColor" can
be "black", "blonde", etc.
Corresponds to the JSON property value
5404 5405 5406 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5404 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5411 5412 5413 5414 5415 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5411 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @name = args[:name] if args.key?(:name) @value = args[:value] if args.key?(:value) end |