Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1FaceFrame

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Deprecated. No effect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1FaceFrame

Returns a new instance of GoogleCloudVideointelligenceV1p3beta1FaceFrame.



5646
5647
5648
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5646

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#normalized_bounding_boxesArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1NormalizedBoundingBox>

Normalized Bounding boxes in a frame. There can be more than one boxes if the same face is detected in multiple locations within the current frame. Corresponds to the JSON property normalizedBoundingBoxes



5638
5639
5640
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5638

def normalized_bounding_boxes
  @normalized_bounding_boxes
end

#time_offsetString

Time-offset, relative to the beginning of the video, corresponding to the video frame for this location. Corresponds to the JSON property timeOffset

Returns:

  • (String)


5644
5645
5646
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5644

def time_offset
  @time_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5651
5652
5653
5654
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5651

def update!(**args)
  @normalized_bounding_boxes = args[:normalized_bounding_boxes] if args.key?(:normalized_bounding_boxes)
  @time_offset = args[:time_offset] if args.key?(:time_offset)
end