Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1LabelAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Label annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1LabelAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1p3beta1LabelAnnotation.



5707
5708
5709
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5707

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_entitiesArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1Entity>

Common categories for the detected entity. For example, when the label is Terrier, the category is likely dog. And in some cases there might be more than one categories e.g., Terrier could also be a pet. Corresponds to the JSON property categoryEntities



5685
5686
5687
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5685

def category_entities
  @category_entities
end

#entityGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1Entity

Detected entity from video analysis. Corresponds to the JSON property entity



5690
5691
5692
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5690

def entity
  @entity
end

#framesArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1LabelFrame>

All video frames where a label was detected. Corresponds to the JSON property frames



5695
5696
5697
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5695

def frames
  @frames
end

#segmentsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1LabelSegment>

All video segments where a label was detected. Corresponds to the JSON property segments



5700
5701
5702
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5700

def segments
  @segments
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


5705
5706
5707
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5705

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5712
5713
5714
5715
5716
5717
5718
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5712

def update!(**args)
  @category_entities = args[:category_entities] if args.key?(:category_entities)
  @entity = args[:entity] if args.key?(:entity)
  @frames = args[:frames] if args.key?(:frames)
  @segments = args[:segments] if args.key?(:segments)
  @version = args[:version] if args.key?(:version)
end