Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1LogoRecognitionAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Annotation corresponding to one detected, tracked and recognized logo class.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1LogoRecognitionAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1p3beta1LogoRecognitionAnnotation.



5793
5794
5795
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5793

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entityGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1Entity

Detected entity from video analysis. Corresponds to the JSON property entity



5779
5780
5781
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5779

def entity
  @entity
end

#segmentsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1VideoSegment>

All video segments where the recognized logo appears. There might be multiple instances of the same logo class appearing in one VideoSegment. Corresponds to the JSON property segments



5785
5786
5787
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5785

def segments
  @segments
end

#tracksArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1Track>

All logo tracks where the recognized logo appears. Each track corresponds to one logo instance appearing in consecutive frames. Corresponds to the JSON property tracks



5791
5792
5793
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5791

def tracks
  @tracks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5798
5799
5800
5801
5802
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5798

def update!(**args)
  @entity = args[:entity] if args.key?(:entity)
  @segments = args[:segments] if args.key?(:segments)
  @tracks = args[:tracks] if args.key?(:tracks)
end