Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1ObjectTrackingAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Annotations corresponding to one tracked object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1ObjectTrackingAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1p3beta1ObjectTrackingAnnotation.



5935
5936
5937
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5935

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

Object category's labeling confidence of this track. Corresponds to the JSON property confidence

Returns:

  • (Float)


5901
5902
5903
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5901

def confidence
  @confidence
end

#entityGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1Entity

Detected entity from video analysis. Corresponds to the JSON property entity



5906
5907
5908
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5906

def entity
  @entity
end

#framesArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1ObjectTrackingFrame>

Information corresponding to all frames where this object track appears. Non- streaming batch mode: it may be one or multiple ObjectTrackingFrame messages in frames. Streaming mode: it can only be one ObjectTrackingFrame message in frames. Corresponds to the JSON property frames



5914
5915
5916
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5914

def frames
  @frames
end

#segmentGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1VideoSegment

Video segment. Corresponds to the JSON property segment



5919
5920
5921
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5919

def segment
  @segment
end

#track_idFixnum

Streaming mode ONLY. In streaming mode, we do not know the end time of a tracked object before it is completed. Hence, there is no VideoSegment info returned. Instead, we provide a unique identifiable integer track_id so that the customers can correlate the results of the ongoing ObjectTrackAnnotation of the same track_id over time. Corresponds to the JSON property trackId

Returns:

  • (Fixnum)


5928
5929
5930
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5928

def track_id
  @track_id
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


5933
5934
5935
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5933

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5940
5941
5942
5943
5944
5945
5946
5947
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5940

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @entity = args[:entity] if args.key?(:entity)
  @frames = args[:frames] if args.key?(:frames)
  @segment = args[:segment] if args.key?(:segment)
  @track_id = args[:track_id] if args.key?(:track_id)
  @version = args[:version] if args.key?(:version)
end