Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1SpeechRecognitionAlternative

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Alternative hypotheses (a.k.a. n-best list).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1SpeechRecognitionAlternative

Returns a new instance of GoogleCloudVideointelligenceV1p3beta1SpeechRecognitionAlternative.



6053
6054
6055
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6053

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

Output only. The confidence estimate between 0.0 and 1.0. A higher number indicates an estimated greater likelihood that the recognized words are correct. This field is set only for the top alternative. This field is not guaranteed to be accurate and users should not rely on it to be always provided. The default of 0.0 is a sentinel value indicating confidence was not set. Corresponds to the JSON property confidence

Returns:

  • (Float)


6039
6040
6041
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6039

def confidence
  @confidence
end

#transcriptString

Transcript text representing the words that the user spoke. Corresponds to the JSON property transcript

Returns:

  • (String)


6044
6045
6046
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6044

def transcript
  @transcript
end

#wordsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1WordInfo>

Output only. A list of word-specific information for each recognized word. Note: When enable_speaker_diarization is set to true, you will see all the words from the beginning of the audio. Corresponds to the JSON property words



6051
6052
6053
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6051

def words
  @words
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6058
6059
6060
6061
6062
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6058

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @transcript = args[:transcript] if args.key?(:transcript)
  @words = args[:words] if args.key?(:words)
end