Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1StreamingVideoAnnotationResults

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb

Overview

Streaming annotation results corresponding to a portion of the video that is currently being processed. Only ONE type of annotation will be specified in the response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1StreamingVideoAnnotationResults

Returns a new instance of GoogleCloudVideointelligenceV1p3beta1StreamingVideoAnnotationResults.



6170
6171
6172
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6170

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#explicit_annotationGoogle::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1ExplicitContentAnnotation

Explicit content annotation (based on per-frame visual signals only). If no explicit content has been detected in a frame, no annotations are present for that frame. Corresponds to the JSON property explicitAnnotation



6148
6149
6150
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6148

def explicit_annotation
  @explicit_annotation
end

#frame_timestampString

Timestamp of the processed frame in microseconds. Corresponds to the JSON property frameTimestamp

Returns:

  • (String)


6153
6154
6155
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6153

def frame_timestamp
  @frame_timestamp
end

#label_annotationsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1LabelAnnotation>

Label annotation results. Corresponds to the JSON property labelAnnotations



6158
6159
6160
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6158

def label_annotations
  @label_annotations
end

#object_annotationsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1ObjectTrackingAnnotation>

Object tracking results. Corresponds to the JSON property objectAnnotations



6163
6164
6165
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6163

def object_annotations
  @object_annotations
end

#shot_annotationsArray<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1VideoSegment>

Shot annotation results. Each shot is represented as a video segment. Corresponds to the JSON property shotAnnotations



6168
6169
6170
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6168

def shot_annotations
  @shot_annotations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6175
6176
6177
6178
6179
6180
6181
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6175

def update!(**args)
  @explicit_annotation = args[:explicit_annotation] if args.key?(:explicit_annotation)
  @frame_timestamp = args[:frame_timestamp] if args.key?(:frame_timestamp)
  @label_annotations = args[:label_annotations] if args.key?(:label_annotations)
  @object_annotations = args[:object_annotations] if args.key?(:object_annotations)
  @shot_annotations = args[:shot_annotations] if args.key?(:shot_annotations)
end