Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1VideoAnnotationProgress
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1VideoAnnotationProgress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb
Overview
Annotation progress for a single video.
Instance Attribute Summary collapse
-
#export_status ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1ExportToOutputUriStatus
Status of exporting annotation response to user specified
output_uri. -
#feature ⇒ String
Specifies which feature is being tracked if the request contains more than one feature.
-
#input_uri ⇒ String
Video file location in Cloud Storage.
-
#progress_percent ⇒ Fixnum
Approximate percentage processed thus far.
-
#segment ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1VideoSegment
Video segment.
-
#start_time ⇒ String
Time when the request was received.
-
#update_time ⇒ String
Time of the most recent update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1VideoAnnotationProgress
constructor
A new instance of GoogleCloudVideointelligenceV1p3beta1VideoAnnotationProgress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1VideoAnnotationProgress
Returns a new instance of GoogleCloudVideointelligenceV1p3beta1VideoAnnotationProgress.
6400 6401 6402 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6400 def initialize(**args) update!(**args) end |
Instance Attribute Details
#export_status ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1ExportToOutputUriStatus
Status of exporting annotation response to user specified output_uri.
Corresponds to the JSON property exportStatus
6366 6367 6368 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6366 def export_status @export_status end |
#feature ⇒ String
Specifies which feature is being tracked if the request contains more than one
feature.
Corresponds to the JSON property feature
6372 6373 6374 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6372 def feature @feature end |
#input_uri ⇒ String
Video file location in Cloud Storage.
Corresponds to the JSON property inputUri
6377 6378 6379 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6377 def input_uri @input_uri end |
#progress_percent ⇒ Fixnum
Approximate percentage processed thus far. Guaranteed to be 100 when fully
processed.
Corresponds to the JSON property progressPercent
6383 6384 6385 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6383 def progress_percent @progress_percent end |
#segment ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1VideoSegment
Video segment.
Corresponds to the JSON property segment
6388 6389 6390 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6388 def segment @segment end |
#start_time ⇒ String
Time when the request was received.
Corresponds to the JSON property startTime
6393 6394 6395 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6393 def start_time @start_time end |
#update_time ⇒ String
Time of the most recent update.
Corresponds to the JSON property updateTime
6398 6399 6400 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6398 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6405 6406 6407 6408 6409 6410 6411 6412 6413 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6405 def update!(**args) @export_status = args[:export_status] if args.key?(:export_status) @feature = args[:feature] if args.key?(:feature) @input_uri = args[:input_uri] if args.key?(:input_uri) @progress_percent = args[:progress_percent] if args.key?(:progress_percent) @segment = args[:segment] if args.key?(:segment) @start_time = args[:start_time] if args.key?(:start_time) @update_time = args[:update_time] if args.key?(:update_time) end |