Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1SpeechRecognitionAlternative
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1SpeechRecognitionAlternative
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb
Overview
Alternative hypotheses (a.k.a. n-best list).
Instance Attribute Summary collapse
-
#confidence ⇒ Float
Output only.
-
#transcript ⇒ String
Transcript text representing the words that the user spoke.
-
#words ⇒ Array<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1WordInfo>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1SpeechRecognitionAlternative
constructor
A new instance of GoogleCloudVideointelligenceV1SpeechRecognitionAlternative.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1SpeechRecognitionAlternative
Returns a new instance of GoogleCloudVideointelligenceV1SpeechRecognitionAlternative.
990 991 992 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 990 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence ⇒ Float
Output only. The confidence estimate between 0.0 and 1.0. A higher number
indicates an estimated greater likelihood that the recognized words are
correct. This field is set only for the top alternative. This field is not
guaranteed to be accurate and users should not rely on it to be always
provided. The default of 0.0 is a sentinel value indicating confidence was
not set.
Corresponds to the JSON property confidence
976 977 978 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 976 def confidence @confidence end |
#transcript ⇒ String
Transcript text representing the words that the user spoke.
Corresponds to the JSON property transcript
981 982 983 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 981 def transcript @transcript end |
#words ⇒ Array<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1WordInfo>
Output only. A list of word-specific information for each recognized word.
Note: When enable_speaker_diarization is set to true, you will see all the
words from the beginning of the audio.
Corresponds to the JSON property words
988 989 990 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 988 def words @words end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
995 996 997 998 999 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 995 def update!(**args) @confidence = args[:confidence] if args.key?(:confidence) @transcript = args[:transcript] if args.key?(:transcript) @words = args[:words] if args.key?(:words) end |