Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1VideoAnnotationProgress
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1VideoAnnotationProgress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb
Overview
Annotation progress for a single video.
Instance Attribute Summary collapse
-
#export_status ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1ExportToOutputUriStatus
Status of exporting annotation response to user specified
output_uri. -
#feature ⇒ String
Specifies which feature is being tracked if the request contains more than one feature.
-
#input_uri ⇒ String
Video file location in Cloud Storage.
-
#progress_percent ⇒ Fixnum
Approximate percentage processed thus far.
-
#segment ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1VideoSegment
Video segment.
-
#start_time ⇒ String
Time when the request was received.
-
#update_time ⇒ String
Time of the most recent update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1VideoAnnotationProgress
constructor
A new instance of GoogleCloudVideointelligenceV1VideoAnnotationProgress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1VideoAnnotationProgress
Returns a new instance of GoogleCloudVideointelligenceV1VideoAnnotationProgress.
1379 1380 1381 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1379 def initialize(**args) update!(**args) end |
Instance Attribute Details
#export_status ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1ExportToOutputUriStatus
Status of exporting annotation response to user specified output_uri.
Corresponds to the JSON property exportStatus
1345 1346 1347 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1345 def export_status @export_status end |
#feature ⇒ String
Specifies which feature is being tracked if the request contains more than one
feature.
Corresponds to the JSON property feature
1351 1352 1353 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1351 def feature @feature end |
#input_uri ⇒ String
Video file location in Cloud Storage.
Corresponds to the JSON property inputUri
1356 1357 1358 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1356 def input_uri @input_uri end |
#progress_percent ⇒ Fixnum
Approximate percentage processed thus far. Guaranteed to be 100 when fully
processed.
Corresponds to the JSON property progressPercent
1362 1363 1364 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1362 def progress_percent @progress_percent end |
#segment ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1VideoSegment
Video segment.
Corresponds to the JSON property segment
1367 1368 1369 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1367 def segment @segment end |
#start_time ⇒ String
Time when the request was received.
Corresponds to the JSON property startTime
1372 1373 1374 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1372 def start_time @start_time end |
#update_time ⇒ String
Time of the most recent update.
Corresponds to the JSON property updateTime
1377 1378 1379 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1377 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1384 1385 1386 1387 1388 1389 1390 1391 1392 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 1384 def update!(**args) @export_status = args[:export_status] if args.key?(:export_status) @feature = args[:feature] if args.key?(:feature) @input_uri = args[:input_uri] if args.key?(:input_uri) @progress_percent = args[:progress_percent] if args.key?(:progress_percent) @segment = args[:segment] if args.key?(:segment) @start_time = args[:start_time] if args.key?(:start_time) @update_time = args[:update_time] if args.key?(:update_time) end |