Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1LogoRecognitionAnnotation
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1LogoRecognitionAnnotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb
Overview
Annotation corresponding to one detected, tracked and recognized logo class.
Instance Attribute Summary collapse
-
#entity ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1Entity
Detected entity from video analysis.
-
#segments ⇒ Array<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1VideoSegment>
All video segments where the recognized logo appears.
-
#tracks ⇒ Array<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1Track>
All logo tracks where the recognized logo appears.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1LogoRecognitionAnnotation
constructor
A new instance of GoogleCloudVideointelligenceV1p1beta1LogoRecognitionAnnotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p1beta1LogoRecognitionAnnotation
Returns a new instance of GoogleCloudVideointelligenceV1p1beta1LogoRecognitionAnnotation.
3331 3332 3333 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3331 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entity ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1Entity
Detected entity from video analysis.
Corresponds to the JSON property entity
3317 3318 3319 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3317 def entity @entity end |
#segments ⇒ Array<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1VideoSegment>
All video segments where the recognized logo appears. There might be multiple
instances of the same logo class appearing in one VideoSegment.
Corresponds to the JSON property segments
3323 3324 3325 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3323 def segments @segments end |
#tracks ⇒ Array<Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p1beta1Track>
All logo tracks where the recognized logo appears. Each track corresponds to
one logo instance appearing in consecutive frames.
Corresponds to the JSON property tracks
3329 3330 3331 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3329 def tracks @tracks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3336 3337 3338 3339 3340 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 3336 def update!(**args) @entity = args[:entity] if args.key?(:entity) @segments = args[:segments] if args.key?(:segments) @tracks = args[:tracks] if args.key?(:tracks) end |