Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb
Overview
Annotation progress for a single video.
Instance Attribute Summary collapse
-
#export_status ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1ExportToOutputUriStatus
Status of exporting annotation response to user specified
output_uri. -
#feature ⇒ String
Specifies which feature is being tracked if the request contains more than one feature.
-
#input_uri ⇒ String
Video file location in Cloud Storage.
-
#progress_percent ⇒ Fixnum
Approximate percentage processed thus far.
-
#segment ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1VideoSegment
Video segment.
-
#start_time ⇒ String
Time when the request was received.
-
#update_time ⇒ String
Time of the most recent update.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress
constructor
A new instance of GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress
Returns a new instance of GoogleCloudVideointelligenceV1p2beta1VideoAnnotationProgress.
5012 5013 5014 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5012 def initialize(**args) update!(**args) end |
Instance Attribute Details
#export_status ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1ExportToOutputUriStatus
Status of exporting annotation response to user specified output_uri.
Corresponds to the JSON property exportStatus
4978 4979 4980 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4978 def export_status @export_status end |
#feature ⇒ String
Specifies which feature is being tracked if the request contains more than one
feature.
Corresponds to the JSON property feature
4984 4985 4986 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4984 def feature @feature end |
#input_uri ⇒ String
Video file location in Cloud Storage.
Corresponds to the JSON property inputUri
4989 4990 4991 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4989 def input_uri @input_uri end |
#progress_percent ⇒ Fixnum
Approximate percentage processed thus far. Guaranteed to be 100 when fully
processed.
Corresponds to the JSON property progressPercent
4995 4996 4997 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 4995 def progress_percent @progress_percent end |
#segment ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p2beta1VideoSegment
Video segment.
Corresponds to the JSON property segment
5000 5001 5002 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5000 def segment @segment end |
#start_time ⇒ String
Time when the request was received.
Corresponds to the JSON property startTime
5005 5006 5007 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5005 def start_time @start_time end |
#update_time ⇒ String
Time of the most recent update.
Corresponds to the JSON property updateTime
5010 5011 5012 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5010 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5017 5018 5019 5020 5021 5022 5023 5024 5025 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 5017 def update!(**args) @export_status = args[:export_status] if args.key?(:export_status) @feature = args[:feature] if args.key?(:feature) @input_uri = args[:input_uri] if args.key?(:input_uri) @progress_percent = args[:progress_percent] if args.key?(:progress_percent) @segment = args[:segment] if args.key?(:segment) @start_time = args[:start_time] if args.key?(:start_time) @update_time = args[:update_time] if args.key?(:update_time) end |