Class: Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1StreamingAnnotateVideoResponse
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1StreamingAnnotateVideoResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1/classes.rb,
lib/google/apis/videointelligence_v1/representations.rb,
lib/google/apis/videointelligence_v1/representations.rb
Overview
StreamingAnnotateVideoResponse is the only message returned to the client by
StreamingAnnotateVideo. A series of zero or more
StreamingAnnotateVideoResponse messages are streamed back to the client.
Instance Attribute Summary collapse
-
#annotation_results ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1StreamingVideoAnnotationResults
Streaming annotation results corresponding to a portion of the video that is currently being processed.
-
#annotation_results_uri ⇒ String
Google Cloud Storage URI that stores annotation results of one streaming session in JSON format.
-
#error ⇒ Google::Apis::VideointelligenceV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1StreamingAnnotateVideoResponse
constructor
A new instance of GoogleCloudVideointelligenceV1p3beta1StreamingAnnotateVideoResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1p3beta1StreamingAnnotateVideoResponse
Returns a new instance of GoogleCloudVideointelligenceV1p3beta1StreamingAnnotateVideoResponse.
6125 6126 6127 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6125 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotation_results ⇒ Google::Apis::VideointelligenceV1::GoogleCloudVideointelligenceV1p3beta1StreamingVideoAnnotationResults
Streaming annotation results corresponding to a portion of the video that is
currently being processed. Only ONE type of annotation will be specified in
the response.
Corresponds to the JSON property annotationResults
6106 6107 6108 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6106 def annotation_results @annotation_results end |
#annotation_results_uri ⇒ String
Google Cloud Storage URI that stores annotation results of one streaming
session in JSON format. It is the annotation_result_storage_directory from the
request followed by '/cloud_project_number-session_id'.
Corresponds to the JSON property annotationResultsUri
6113 6114 6115 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6113 def annotation_results_uri @annotation_results_uri end |
#error ⇒ Google::Apis::VideointelligenceV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
6123 6124 6125 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6123 def error @error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6130 6131 6132 6133 6134 |
# File 'lib/google/apis/videointelligence_v1/classes.rb', line 6130 def update!(**args) @annotation_results = args[:annotation_results] if args.key?(:annotation_results) @annotation_results_uri = args[:annotation_results_uri] if args.key?(:annotation_results_uri) @error = args[:error] if args.key?(:error) end |